@@ -1,18 +1,7 @@
 /*
-  Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "jobtrackersearchwidget.h"
@@ -25,7 +14,7 @@
 JobTrackerSearchWidget::JobTrackerSearchWidget(QWidget *parent)
     : QWidget(parent)
 {
-    QHBoxLayout *mainLayout = new QHBoxLayout(this);
+    auto *mainLayout = new QHBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainlayout"));
     mainLayout->setContentsMargins(0, 0, 0, 0);
 
@@ -41,7 +30,6 @@ JobTrackerSearchWidget::JobTrackerSearchWidget(QWidget *parent)
     mainLayout->addWidget(mSelectOnlyError);
     connect(mSelectOnlyError, &QCheckBox::toggled, this, &JobTrackerSearchWidget::selectOnlyErrorChanged);
 
-
     mSelectColumn = new QComboBox(this);
     mSelectColumn->setObjectName(QStringLiteral("selectcolumn"));
     mainLayout->addWidget(mSelectColumn);
@@ -58,7 +46,6 @@ JobTrackerSearchWidget::JobTrackerSearchWidget(QWidget *parent)
 
 JobTrackerSearchWidget::~JobTrackerSearchWidget()
 {
-
 }
 
 void JobTrackerSearchWidget::slotColumnChanged(int index)
