@@ -1,25 +1,11 @@
 /*
-    Copyright (c) 2009 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2009 Volker Krause <vkrause@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-    USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "notificationmodel.h"
 
-
 #include <QLocale>
 
 #include "akonadiconsole_debug.h"
@@ -33,9 +19,8 @@ Q_DECLARE_METATYPE(Akonadi::ChangeNotification)
 
 using namespace Akonadi;
 
-NotificationModel::NotificationModel(QObject *parent) :
-    QAbstractItemModel(parent),
-    m_monitor(nullptr)
+NotificationModel::NotificationModel(QObject *parent)
+    : QAbstractItemModel(parent)
 {
 }
 
@@ -178,7 +163,8 @@ QVariant NotificationModel::data(const QModelIndex &index, int role) const
             }
         case IdsColumn:
             switch (msg.type()) {
-            case ChangeNotification::Items: {
+            case ChangeNotification::Items:
+            {
                 QStringList rv;
                 const auto items = Protocol::cmdCast<Protocol::ItemChangeNotification>(msg.notification()).items();
                 for (const auto &item : items) {
@@ -197,7 +183,8 @@ QVariant NotificationModel::data(const QModelIndex &index, int role) const
             return {};
         case SessionColumn:
             return msg.notification()->sessionId();
-        case ListenersColumn: {
+        case ListenersColumn:
+        {
             const auto listeners = msg.listeners();
             QStringList rv;
             for (const auto &l : listeners) {
@@ -217,12 +204,18 @@ QVariant NotificationModel::headerData(int section, Qt::Orientation orientation,
 {
     if (role == Qt::DisplayRole && orientation == Qt::Horizontal) {
         switch (section) {
-        case DateColumn: return QStringLiteral("Date");
-        case TypeColumn: return QStringLiteral("Type");
-        case OperationColumn: return QStringLiteral("Operation");
-        case IdsColumn: return QStringLiteral("IDs");
-        case SessionColumn: return QStringLiteral("Session");
-        case ListenersColumn: return QStringLiteral("Listeners");
+        case DateColumn:
+            return QStringLiteral("Date");
+        case TypeColumn:
+            return QStringLiteral("Type");
+        case OperationColumn:
+            return QStringLiteral("Operation");
+        case IdsColumn:
+            return QStringLiteral("IDs");
+        case SessionColumn:
+            return QStringLiteral("Session");
+        case ListenersColumn:
+            return QStringLiteral("Listeners");
         }
     }
     return QAbstractItemModel::headerData(section, orientation, role);
@@ -255,4 +248,3 @@ void NotificationModel::setEnabled(bool enable)
         m_monitor = nullptr;
     }
 }
-
