@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2009 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2009 Volker Krause <vkrause@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-    USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef AKONADICONSOLE_NOTIFICATIONMODEL_H
@@ -25,10 +12,8 @@
 #include <AkonadiCore/Monitor>
 #include <AkonadiCore/ChangeNotification>
 
-namespace Akonadi
-{
-namespace Protocol
-{
+namespace Akonadi {
+namespace Protocol {
 class ChangeNotification;
 }
 }
@@ -63,7 +48,7 @@ public:
 
     Akonadi::Protocol::ChangeNotificationPtr notification(const QModelIndex &index) const;
 
-    bool isEnabled() const
+    Q_REQUIRED_RESULT bool isEnabled() const
     {
         return m_monitor;
     }
