@@ -1,22 +1,9 @@
 /*
     This file is part of Akonadi.
 
-    Copyright (c) 2009 Tobias Koenig <tokoe@kde.org>
+    SPDX-FileCopyrightText: 2009 Tobias Koenig <tokoe@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-    USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include <xapian.h>
@@ -30,7 +17,6 @@
 #include <AkonadiCore/itemsearchjob.h>
 #include <AkonadiCore/SearchQuery>
 
-
 #include <AkonadiSearch/Core/searchstore.h>
 #include <AkonadiSearch/Xapian/xapiansearchstore.h>
 
@@ -51,13 +37,12 @@
 
 SearchWidget::SearchWidget(QWidget *parent)
     : QWidget(parent)
-    , mDatabase(nullptr)
 {
     Akonadi::ControlGui::widgetNeedsAkonadi(this);
 
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
 
-    QHBoxLayout *hbox = new QHBoxLayout;
+    auto *hbox = new QHBoxLayout;
     hbox->addWidget(new QLabel(QStringLiteral("Search store:")), 0, {});
     mStoreCombo = new KComboBox;
     mStoreCombo->setObjectName(QStringLiteral("SearchStoreCombo"));
@@ -70,7 +55,7 @@ SearchWidget::SearchWidget(QWidget *parent)
     mVSplitter = new QSplitter(Qt::Vertical);
     mVSplitter->setObjectName(QStringLiteral("SearchVSplitter"));
     auto w = new QWidget;
-    QVBoxLayout *vbox = new QVBoxLayout(w);
+    auto *vbox = new QVBoxLayout(w);
     vbox->addWidget(new QLabel(QStringLiteral("Search query:")));
     mQueryWidget = new QPlainTextEdit;
     vbox->addWidget(mQueryWidget);
@@ -109,7 +94,6 @@ SearchWidget::SearchWidget(QWidget *parent)
 
     layout->addWidget(mVSplitter);
 
-
     const auto stores = Akonadi::Search::SearchStore::searchStores();
     for (const auto &store : stores) {
         mStoreCombo->addItem(store->types().last(), QVariant::fromValue(store));
@@ -134,7 +118,7 @@ SearchWidget::~SearchWidget()
 
 void SearchWidget::openStore(int idx)
 {
-    auto store = mStoreCombo->itemData(idx, Qt::UserRole).value<QSharedPointer<Akonadi::Search::SearchStore>>();
+    auto store = mStoreCombo->itemData(idx, Qt::UserRole).value<QSharedPointer<Akonadi::Search::SearchStore> >();
     auto xapianStore = store.objectCast<Akonadi::Search::XapianSearchStore>();
     Q_ASSERT(xapianStore);
 
@@ -160,8 +144,6 @@ void SearchWidget::xapianError(const Xapian::Error &e)
                           QStringLiteral("%1: %2").arg(QString::fromUtf8(e.get_type()), QString::fromStdString(e.get_msg())));
 }
 
-
-
 void SearchWidget::search()
 {
     if (!mDatabase) {
@@ -211,7 +193,7 @@ void SearchWidget::fetchItem(const QModelIndex &index)
 
         auto valuesRoot = new QStandardItem(QStringLiteral("Values"));
         mTermModel->appendRow(valuesRoot);
-	const auto end = doc.values_end(); // Xapian 1.2 has different type for _begin() and _end() iters
+        const auto end = doc.values_end(); // Xapian 1.2 has different type for _begin() and _end() iters
         for (auto it = doc.values_begin(); it != end; ++it) {
             valuesRoot->appendRow({ new QStandardItem(QString::fromStdString(*it)),
                                     new QStandardItem(QString::number(it.get_valueno())) });
@@ -221,7 +203,6 @@ void SearchWidget::fetchItem(const QModelIndex &index)
         return;
     }
 
-
     Akonadi::ItemFetchJob *fetchJob = new Akonadi::ItemFetchJob(Akonadi::Item(docId));
     fetchJob->fetchScope().fetchFullPayload();
     connect(fetchJob, &Akonadi::ItemFetchJob::result, this, &SearchWidget::itemFetched);
@@ -236,7 +217,7 @@ void SearchWidget::itemFetched(KJob *job)
         return;
     }
 
-    Akonadi::ItemFetchJob *fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
+    auto *fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
     if (!fetchJob->items().isEmpty()) {
         const Akonadi::Item item = fetchJob->items().first();
         mItemView->setPlainText(QString::fromUtf8(item.payloadData()));
